function assemble_CEQ
screen_size=get(0,'ScreenSize');
pad=30;
vpad=30;
fh=figure('IntegerHandle','off','Name','Assemble CEQ File','NumberTitle','off','Resize','off','MenuBar','none','toolbar','none','Position',[300,screen_size(4)/2-250, 600, 400]);
figsize=get(fh,'Position');

button_width=(figsize(3)-5*pad)/4;
plot_button = uicontrol(fh,'Style','pushbutton','String','Plot New Data','Position',[pad figsize(4)-2*vpad button_width 30],'Callback',@plot_data);
load_button = uicontrol(fh,'Style','pushbutton','String','Load Data','Position',[2*pad+button_width figsize(4)-2*vpad button_width 30],'Callback',@load_data);
write_button = uicontrol(fh,'Style','pushbutton','String','Write Data','Position',[3*pad+2*button_width figsize(4)-2*vpad button_width 30],'Callback',@write_data);
end_button = uicontrol(fh,'Style','pushbutton','String','QUIT','Position',[4*pad+3*button_width figsize(4)-2*vpad button_width 30],'Callback',@end_fn,'ForeGroundcolor',[1 0 0]);

space=3.5*vpad;
assign1_button = uicontrol(fh,'Style','pushbutton','String','Assign F1','Position',[pad figsize(4)-space button_width 30],'Callback',@assign_data);
assign2_button = uicontrol(fh,'Style','pushbutton','String','Assign F2','Position',[2*pad+button_width figsize(4)-space button_width 30],'Callback',@assign_data);
assign3_button = uicontrol(fh,'Style','pushbutton','String','Assign F3','Position',[3*pad+2*button_width figsize(4)-space button_width 30],'Callback',@assign_data);
assign4_button = uicontrol(fh,'Style','pushbutton','String','Assign F4','Position',[4*pad+3*button_width figsize(4)-space button_width 30],'Callback',@assign_data);

H_size=figsize(4)-space-10;
F1_list = uicontrol(fh,'Style','listbox','String',{},'Value',1,'Position',[1*pad+0*button_width 10 button_width H_size],'FontSize',10);
F2_list = uicontrol(fh,'Style','listbox','String',{},'Value',1,'Position',[2*pad+1*button_width 10 button_width H_size],'FontSize',10);
F3_list = uicontrol(fh,'Style','listbox','String',{},'Value',1,'Position',[3*pad+2*button_width 10 button_width H_size],'FontSize',10);
F4_list = uicontrol(fh,'Style','listbox','String',{},'Value',1,'Position',[4*pad+3*button_width 10 button_width H_size],'FontSize',10);

handles.path=[];

uiwait;


close(fh);
try
    close(100)
end

    function end_fn(hObject,eventdata)
        
        uiresume(fh);
        
    end
    function plot_data(hObject,eventdata)
        F1=get(F1_list,'String');
        F2=get(F2_list,'String');
        F3=get(F3_list,'String');
        F4=get(F4_list,'String');
        if isempty(F1) || isempty(F2) || isempty(F3) || isempty(F4)
            warndlg('There are empty filters, can no plot data')
            return
        else
            figure(100)
            clf(100)
            subplot(2,2,1)
            plot(str2num(F1))
            xlabel('Nucleotides')
            ylabel('Intensity')
            title('Filter 1')
            subplot(2,2,2)
            plot(str2num(F2))
            xlabel('Nucleotides')
            ylabel('Intensity')
            title('Filter 2')
            subplot(2,2,3)
            plot(str2num(F3))
            xlabel('Nucleotides')
            ylabel('Intensity')
            title('Filter 3')
            subplot(2,2,4)
            plot(str2num(F4))
            xlabel('Nucleotides')
            ylabel('Intensity')
            title('Filter 4')
        end
        
    end

    function load_data(hObject,eventdata)
        [file,path]=uigetfile({'*.txt';'*.mat'},'Select file to load');
        filename=fullfile(path,file);
        [handles.path,name,ext]=fileparts(filename);
        if strcmp(ext,'.mat')
            [F1,F2,F3,F4]=select_mat(filename);
            
        elseif strcmp(ext,'.txt')
            wb=waitbar(.5,'Read in file');
            [F1,F2,F3,F4]=read_CEQ_txt(filename);
            close(wb)
        else
            return
        end
        set(F1_list,'String',num2str(F1(:)));
        set(F2_list,'String',num2str(F2(:)));
        set(F3_list,'String',num2str(F3(:)));
        set(F4_list,'String',num2str(F4(:)));
        
    end

    function assign_data(hObject,eventdata)
        %function for picking plot
        switch hObject
            case assign1_button
                [picked_F,handles.path]=pick_filter(1,handles.path);
                set(F1_list,'String',num2str(picked_F))
            case assign2_button
                [picked_F,handles.path]=pick_filter(2,handles.path);
                set(F2_list,'String',num2str(picked_F))
            case assign3_button
                [picked_F,handles.path]=pick_filter(3,handles.path);
                set(F3_list,'String',num2str(picked_F))
            case assign4_button
                [picked_F,handles.path]=pick_filter(4,handles.path);
                set(F4_list,'String',num2str(picked_F))
        end
    end

    function write_data(hObject,eventdata)
        F1=str2num(get(F1_list,'String'));
        F2=str2num(get(F2_list,'String'));
        F3=str2num(get(F3_list,'String'));
        F4=str2num(get(F4_list,'String'));
        L=min([length(F1) length(F2) length(F3) length(F4)]);
        [file,path]=uiputfile('savedfile.txt','Save file name');%make sure clean open
        wb=waitbar(0,'Writing to file','Position',[figsize(1) figsize(2) 350 72]);
        fid=fopen(fullfile(path,file),'w');
        str=['Sample Name: Created file ', file,];
        fprintf(fid,'%s\n',str);
        fprintf(fid,'Sample Subject ID:	XXX\n\n');
        fprintf(fid,'Raw Data Output Injection\n\n');
        fprintf(fid,'INDEX\tCAP\tFILTER 1\tFILTER 2\tFILTER 3\tFILTER 4\tCURRENT\tVOLTAGE\tRAW CURR\tTOTAL CURR\tINJ CURR\tINJ VOLT\tINJ TOT CURR\tRTN CURR\n');
        for i=1:5
            fprintf(fid,'%.0f\tX\t%.2f\t%.2f\t%.2f\t%.2f\t0.0\t0.00\t0\t0\t0\t0\t0\t0\t0\n',i,0,0,0,0);
            
        end
        fprintf(fid,'\nRaw Data Output Separation\n\n');
        fprintf(fid,'Start Time (min):\t0.000000\tStop Time:\tXXXXXXX\nSampling Rate (Hz):\t2.000000\tNumber of Points:\t%d\n\n',length(F1));
        fprintf(fid,'INDEX\tCAP\tFILTER 1\tFILTER 2\tFILTER 3\tFILTER 4\tCURRENT\tVOLTAGE\tRAW CURR\tTOTAL CURR\tINJ CURR\tINJ VOLT\tINJ TOT CURR\tRTN CURR\n');
        for i=1:L
            fprintf(fid,'%.0f\tX\t%.0f\t%.0f\t%.0f\t%.0f\t0.0\t0.00\t0\t0\t0\t0\t0\t0\n',i,F1(i),F2(i),F3(i),F4(i));
            waitbar(i/L,wb,'writing to file');
        end
        fclose(fid);%make sure clean close
        close(wb);
        
    end
end

function [picked_F,file_path]=pick_filter(filter_num,path)
F1=[];
F2=[];
F3=[];
F4=[];
if isempty(path)
    path=pwd;
end

while isempty(F1) || isempty(F2) || isempty(F3) || isempty(F4)
    [file,file_path]=uigetfile({'*.txt';'*.mat'},'Select file to read in',path);
    filename=fullfile(file_path,file);
    [file_path,file,ext]=fileparts(filename);
    if strcmp(ext,'.mat')
        %            warndlg('reading mat files not yet implemented completely')
        [F1,F2,F3,F4]=select_mat(filename);
        F1=F1';
        F2=F2';
        F3=F3';
        F4=F4';
    elseif strcmp(ext,'.txt')
        wb=waitbar(.5,'Read in file');
        [F1,F2,F3,F4]=read_CEQ_txt(filename);
        close(wb)
    else
        picked_F=[];
        return
    end
end
% wb=waitbar(.5,'Read in file');
% [F1,F2,F3,F4]=read_CEQ_txt(fullfile(path,file));
% close(wb)
screen_size=get(0,'ScreenSize');
figh=figure('IntegerHandle','off','Name',['Pick Data for Filter ',int2str(filter_num)],'NumberTitle','off','Resize','off','MenuBar','none','toolbar','none','Position',[300,screen_size(4)/2-250, 850, 600]);
figsize=get(figh,'Position');

pad=30;

axisW=(figsize(3)-5*pad)/2;
axisH=(figsize(4)-9*pad)/2;
axis1 = axes('Parent',figh,'Position',[2*pad/figsize(3) (8*pad+axisH)/figsize(4) axisW/figsize(3) axisH/figsize(4)],'box','on');
axis2 = axes('Parent',figh,'Position',[(4*pad+axisW)/figsize(3) (8*pad+axisH)/figsize(4) axisW/figsize(3) axisH/figsize(4)],'box','on');
axis3 = axes('Parent',figh,'Position',[2*pad/figsize(3) (5*pad)/figsize(4) axisW/figsize(3) axisH/figsize(4)],'box','on');
axis4 = axes('Parent',figh,'Position',[(4*pad+axisW)/figsize(3) (5*pad)/figsize(4) axisW/figsize(3) axisH/figsize(4)],'box','on');

plot(axis1,F1)
xlabel(axis1,'Nucleotides')
ylabel(axis1','Intensity')

plot(axis2,F2)
xlabel(axis2,'Nucleotides')
ylabel(axis2','Intensity')

plot(axis3,F3)
xlabel(axis3,'Nucleotides')
ylabel(axis3','Intensity')

plot(axis4,F4)
xlabel(axis4,'Nucleotides')
ylabel(axis4','Intensity')

Assign1_bttn=uicontrol(figh,'Style','pushbutton','FontSize',14,'String','Assign plot','Position',[2*pad       6*pad+axisH axisW pad],'Callback',@assign_data);
Assign2_bttn=uicontrol(figh,'Style','pushbutton','FontSize',14,'String','Assign plot','Position',[4*pad+axisW 6*pad+axisH axisW pad],'Callback',@assign_data);
Assign3_bttn=uicontrol(figh,'Style','pushbutton','FontSize',14,'String','Assign plot','Position',[2*pad       3*pad       axisW pad],'Callback',@assign_data);
Assign4_bttn=uicontrol(figh,'Style','pushbutton','FontSize',14,'String','Assign plot','Position',[4*pad+axisW 3*pad       axisW pad],'Callback',@assign_data);

newfile_bttn=uicontrol(figh,'Style','pushbutton','FontSize',14,'String','Pick new file','Position',[2*pad         1*pad       axisW pad],'Callback',@newfile_data);
zero_bttn=uicontrol(figh,'Style','pushbutton','FontSize',14,'String','Assign Zeros','Position',[4*pad+axisW 1*pad       axisW pad],'Callback',@cancel_data);

    function newfile_data(hObject,eventdata)
        F1=[];F2=[];F3=[];F4=[];
        while isempty(F1) || isempty(F2) || isempty(F3) || isempty(F4)
            [file,path]=uigetfile({'*.txt';'*.mat'},'Select file to read in');
            filename=fullfile(path,file);
            [path,file,ext]=fileparts(filename);
            if strcmp(ext,'.mat')
                %            warndlg('reading mat files not yet implemented completely')
                [F1,F2,F3,F4]=select_mat(filename);
                F1=F1';
                F2=F2';
                F3=F3';
                F4=F4';
            elseif strcmp(ext,'.txt')
                wb=waitbar(.5,'Read in file');
                [F1,F2,F3,F4]=read_CEQ_txt(filename);
                close(wb)
            else
                picked_F=[];
                return
            end
        end
        
        
        plot(axis1,F1)
        xlabel(axis1,'Nucleotides')
        ylabel(axis1','Intensity')
        
        plot(axis2,F2)
        xlabel(axis2,'Nucleotides')
        ylabel(axis2','Intensity')
        
        plot(axis3,F3)
        xlabel(axis3,'Nucleotides')
        ylabel(axis3','Intensity')
        
        plot(axis4,F4)
        xlabel(axis4,'Nucleotides')
        ylabel(axis4','Intensity')
        
    end

    function cancel_data(hObject,eventdata)
        
        picked_F=zeros(size(F1'));
        uiresume(figh);
    end

    function assign_data(hObject,eventdata)
        switch hObject
            case Assign1_bttn
                picked_F=F1';
            case Assign2_bttn
                picked_F=F2';
            case Assign3_bttn
                picked_F=F3';
            case Assign4_bttn
                picked_F=F4';
        end
        uiresume(figh);
    end

uiwait
close(figh)
end

function [F1,F2,F3,F4]=read_CEQ_txt(filename)

if nargin<1 || isempty(filename)
    [file,path]=uigetfile('*.txt','Choose txt file');
    filename=fullfile(path,file);
end

fid=fopen(filename,'r');
tline=1;
Sep_start=0;
IND_start=0;
i=0;
j=0;
while tline ~= -1
    tline=fgets(fid);
    if isempty(strfind(tline,'Separation'))==0
        Sep_start=1;
    end
    
    if isempty(strfind(tline,'INDEX'))==0 & Sep_start==1;
        IND_start=1;
    end
    
    if Sep_start==1 & IND_start==1
        i=i+1;
    end
    
    if i>1 & tline ~= -1
        j=j+1;
        [IND(j), LET(j),F1(j),F2(j),F3(j),F4(j),a,b,c,d,e,f,g,h]=...
            strread(tline,'%d%c%d%d%d%d%f%f%f%f%f%f%f%d');
    end
    
end
fclose(fid);
end

function [F1,F2,F3,F4]=select_mat(filename)
screen_size=get(0,'ScreenSize');
data=load(filename);
if ~isfield(data,'profiles_name')
    warndlg('MAT file does not contain proper fields')
    F1=[];
    F2=[];
    F3=[];
    F4=[];
    return
end
%test to make sure mat has proper pieces
data_h=figure('IntegerHandle','off','Name','Pick data to load','NumberTitle','off','Resize','off','MenuBar','none','toolbar','none','Position',[300,screen_size(4)/2-250, 400, 400]);
fig_size=get(data_h,'Position');
name_list = uicontrol(data_h,'Style','listbox','String',data.profiles_name,'Value',1,'Position',[10 10 fig_size(3)-20 fig_size(4)-20],'FontSize',12,'Callback',@list_data);

    function list_data(hObject,eventdata)
        resultsStr = get(name_list,'String');
        numResults = size(resultsStr,1);
        if numResults==0
            return
        end
        currentVal = get(name_list,'Value');
        
        F1=data.profiles{currentVal}(:,1);
        F2=data.profiles{currentVal}(:,2);
        F3=data.profiles{currentVal}(:,3);
        F4=data.profiles{currentVal}(:,4);
        
        uiresume(data_h);
    end
uiwait(data_h);
close(data_h);
end