function gui_profile_align
%GUI for aligning profiles from a choosen reference file
%can process multiple files
%will save the data in a file of your choosing
%will also plot a file containing the data
%
%
screen_size=get(0,'Screensize');
fh=figure('IntegerHandle','off','Name','Group Processing','NumberTitle','off','Resize','off','MenuBar','none','toolbar','none',...
    'Position',[screen_size(3)/4, screen_size(4)/4, 560,420]);
figsize=get(fh,'Position');
lbh = uicontrol(fh,'Style','listbox','String',{},'SelectionHighlight','off','Selected','off',...
    'Value',1,'Position',[15 10 figsize(3)-30 200],'FontSize',14,'Callback',@list_entry);
ladder=[420 400 380 360 340 320 300 280 260 240 220 200 190 180 160 140 120 100 90 80 70 60 20];

return_button = uicontrol(fh,'Style','pushbutton','String','END','Position',[figsize(3)-100 250 60 30],'Foreground',[1,0,0],'Callback',@return_fn);
addref_button = uicontrol(fh,'Style','pushbutton','String','Add Refrence File','Position',[10 250 100 30],'Callback',@ref_entry);
ladder_button = uicontrol(fh,'Style','pushbutton','String','400 Ladder','Position',[10 220 100 30],'Callback',@set_ladder);

add_button = uicontrol(fh,'Style','pushbutton','String','Add File','Position',[130 280 100 30],'Callback',@add_entry);
diradd_button = uicontrol(fh,'Style','pushbutton','String','Add directory','Position',[130 250 100 30],'Callback',@add_dir);
clear_button = uicontrol(fh,'Style','pushbutton','String','Clear Entries','Position',[130 220 100 30],'Callback',@clear_entry);
run_button = uicontrol(fh,'Style','pushbutton','String','Run Alignment','Position',[250 250 90 30],'Callback',@run_scale);
plot_button = uicontrol(fh,'Style','pushbutton','String','Plot Results','Position',[350 250 90 30],'Callback',@plot_fun);

ref_label = uicontrol(fh,'Style','text','String','no reference file chosen',...
    'Position',[10 figsize(4)-105 figsize(3)-20 75],'FontSize',18,'BackgroundColor',[1 1 1]);

ref_tag=uicontrol(fh,'Style','text','String','Reference file:',...
    'Position',[10 figsize(4)-30 figsize(3)-20 20],'FontSize',20,'ForegroundColor',[1,0,0]);

    function return_fn(hObject,eventdata)%end button for terminating gui
        uiresume(fh);
    end
    function add_entry(hObject,eventdata)%adds an entry to the list box
        list = get(lbh,'String');
        [file,path]=uigetfile('*.txt','Pick file to add to comparison');
        filename=fullfile(path,file);

        list{length(list)+1}=filename;
        set(lbh,'String',list);

    end

    function add_dir(hObject,eventdata)%adds a directroy to the list box
        list = get(lbh,'String');
        [path]=uigetdir('.','Pick dir to add to comparison');

        dir_files=dir(fullfile(path,'*.txt'));
        if isempty(dir_files)
            warndlg(['No text files found in ',path])
            return
        end
        for i=1:length(dir_files)
            filename=fullfile(path,dir_files(i).name);

            list{length(list)+1}=filename;

        end
        set(lbh,'String',list);
    end
    function clear_entry(hObject,eventdata)%clears the list of lists
        set(lbh,'String',{});
    end

    function list_entry(hObject,eventdata)%removes the selected form the list
        resultsStr = get(lbh,'String');
        numResults = size(resultsStr,1);
        if   numResults==0
            return
        end
        currentVal = get(lbh,'Value');

        % Remove the data and list entry for the selected value
        if isunix%if statement to test if this is on a PC
            file=resultsStr{currentVal}(find(resultsStr{currentVal}=='/',1,'last')+1:end);
        else
            file=resultsStr{currentVal}(find(resultsStr{currentVal}=='\',1,'last')+1:end);
        end
        ans=questdlg(['Remove ',file,'?'],'Confirm Deleate','Yes','Cancel','Yes');
        if ~strcmp('Yes',ans)
            return;
        end
        resultsStr(currentVal) =[];
        if isequal(numResults,length(currentVal)),
            currentVal = 1;
            set(lbh,'String',{},'Value',1)
            return;
        end
        % Ensure that list box Value is valid, then reset Value and String
        set(lbh,'String',resultsStr,'Value',1)
    end

    function ref_entry(hObject,eventdata)%picks the refrence file
        [file,path]=uigetfile('*.txt','Pick Refrence file');
        if isempty(file)
            return
        end
        filename=fullfile(path,file);
        set(ref_label,'String',filename);
        set(ref_tag,'ForegroundColor',[0 0 0])
    end


    function run_scale(hObject,eventdata)%runs the batch scaling of the files
        list=get(lbh,'String');
        if isempty(list)
            errordlg('No comparison files selected')
            return;
        end

        ref_file=get(ref_label,'String');
        if exist(ref_file)~=2
            errordlg('No reference file chosen')
            return
        end
        wbar=waitbar(0,'Aligning Runs','Position',[figsize(1) figsize(2) 350 72]);
        %        tmp=get(wbar,'Position')
        ladder(1)
        for i=1:length(list)
            %[path,compfiles(i).name]
            profiles_align_tmp=two_profile_align(ref_file,list{i},false,ladder);
            profiles{1}=profiles_align_tmp(:,[1:4]);
            profiles_name{1}=ref_file;
            profiles{i+1}=profiles_align_tmp(:,[5:8]);
            profiles_name{i+1}=list{i};
            waitbar(i/length(list),wbar,['Aligning Runs: ',int2str(i),' of ',length(list),' files done']);
        end
        [path,fname]=fileparts(ref_file);
        uisave({'profiles','profiles_name'},fullfile(path,'multiple_profiles.mat'))
        close(wbar);
    end
    function set_ladder(hObject,eventdata)
        [ladder,laddername]=select_ladder2(hObject);
        %        'in set ladder after selection'
        %        laddername
        set(ladder_button,'String',laddername);
    end

uiwait;
try
    close(fh);
end
end

function [ladder,ladder_name]=select_ladder2(L_button)
%ladder=[420 400 380 360 340 320 300 280 260 240 220 200 190 180 160 140 120 100 90 80 70 60 20];
ladder=[];
ladder_name='400 ladder';
screen_size=get(0,'Screensize');
fh_ladder=figure('IntegerHandle','off','Name','Select Ladder','NumberTitle','off','Resize','off','MenuBar','none','toolbar','none',...
    'Position',[screen_size(3)/4, screen_size(4)/4, 120,210]);
figsize=get(fh_ladder,'Position');

return_button = uicontrol(fh_ladder,'Style','pushbutton','String','END','Position',[10 10 100 30],'Foreground',[1,0,0],'Callback',@close_ladder);
create_button = uicontrol(fh_ladder,'Style','pushbutton','String','create ladder','Position',[10 50 100 30],'Callback',@create_ladder);
ladder400_button = uicontrol(fh_ladder,'Style','pushbutton','String','400 ladder','Position',[10 170 100 30],'Callback',@base_ladder);
ladder600_button = uicontrol(fh_ladder,'Style','pushbutton','String','600 ladder','Position',[10 130 100 30],'Callback',@base_ladder);
read_button = uicontrol(fh_ladder,'Style','pushbutton','String','read ladder','Position',[10 90 100 30],'Callback',@read_ladder);

    function read_ladder(hObject,eventdata)
        [name,path]=uigetfile('*.txt','pick file with ladder values');
        data=importdata(fullfile(path,name));
        if isstruct(data)
            data=data.data;
        end

        if size(data,1)<size(data,2)
            data=data';
        end
        if size(data,2)>1
            data=data(:,1);
        end
        [path,name,ext]=fileparts(name);
        ladder=data;
        ladder_name=name;
        close_ladder(hObject,eventdata,ladder);
    end

    function close_ladder(hObject,eventdata,ladder)
        ladder
        %        ladder_name
        set(L_button,'String',ladder_name);
        set(L_button,'Foreground',[1,0,0]);

        uiresume(fh_ladder);
        close(fh_ladder);
    end

    function base_ladder(hObject,eventdata)

        if hObject==ladder400_button
            ladder=[420 400 380 360 340 320 300 280 260 240 220 200 190 180 160 140 120 100 90 80 70 60 20];
            ladder_name='400 ladder';
        elseif hObject==ladder600_button

            ladder=[640 620 600 580 560 540 520 500 480 460 440 420 400 380 360 340 320 300 280 260 240 220 200 190 180 160 140 120 100 90 80 70 60];
            ladder_name='600 ladder';
        else
            ladder=[420 400 380 360 340 320 300 280 260 240 220 200 190 180 160 140 120 100 90 80 70 60 20];
            ladder_name='400 ladder';
        end
        close_ladder(hObject,eventdata,ladder)
    end

    function create_ladder(hObject,eventdata)
        ladder_name='custom ladder';

        ladder=create_ladder_fn(hObject,eventdata);
        close_ladder(hObject,eventdata,lader)
    end
uiwait(fh_ladder);
end

function plot_fun(hObject,eventdata)%runs the plot function of the data
plot_profiles
end

function ladder=create_ladder_fn(hObject,eventdata)
ladder=[];
screen_size=get(0,'Screensize');
fig_win=figure('Integerhandle','off','Name','Ladder','NumberTitle','off','MenuBar','none','toolbar','none',...
    'Position',[screen_size(3)/4,screen_size(4)/4,150,400]);
end_bttn=uicontrol(fig_win,'Style','pushbutton','String','end','Position',[10,10,130,30],'Foreground',[1,0,0],'Callback',@end_function);

fig_list = uicontrol(fig_win,'Style','listbox','String',{},'SelectionHighlight','off','Selected','off',...
    'Value',1,'Position',[10 50 130 340],'FontSize',14,'Callback',@list_entry);


    function end_function(hObject,event)
        tmp_ladder=get(fig_list,'String');
        for i=1:length(tmp_ladder)
            ladder(i)=str2num(tmp_ladder{i});
        end
        uiresume(fig_win);
        close(fig_win)
    end

    function list_entry(hObject,event)
        resultsStr = get(fig_list,'String');
        numResults = size(resultsStr,1);
        input=inputdlg('input ladder entry:','ladder entries');
        if isempty(input)

        else
            list=get(fig_list,'String');
            if isempty(list)
                list=input;
            else
                list{length(list)+1}=input{1};
            end
            set(fig_list,'String',list,'Value',1);
        end
    end
uiwait(fig_win);
end