function [profiles_align,filenames]=two_profile_align(basefilename,compfilename,verbos,ladder)
%[profiles_align,filenames]=two_profile_align(basefilename,compfilename,ver
%bos)
base=2;
if nargin<1 || isempty(basefilename)
    [file,path]=uigetfile('*.txt','Select base file');
    basefilename=fullfile(path,file);
end
if nargin<2 || isempty(compfilename)
    [file,path]=uigetfile('*.txt','Select comparison file');
    compfilename=fullfile(path,file);
end
if nargin<3 || isempty(verbos)
    verbos=false;
end

if nargin<4 || isempty(ladder)
    guideruler=[420 400 380 360 340 320 300 280 260 240 220 200 190 180 160 140 120 100 90 80 70 60 20];
else
    guideruler=sort(ladder,'descend');
    if size(guideruler,1)>size(guideruler,2)
        guideruler=guideruler';
    end
end

%flag to turn on scaling or off, (false is off, true is on)
scale_alignment=true;


filenames={basefilename,compfilename};


[F1,F2,F3,F4]=read_CEQ_txt(basefilename);%read in file from CEQ format
[F1_2,F2_2,F3_2,F4_2]=read_CEQ_txt(compfilename);

if length(F4)~=length(F4_2)
    min_length=min(length(F4),length(F4_2));%
    F1=F1(1:min_length);
    F2=F2(1:min_length);
    F3=F3(1:min_length);
    F4=F4(1:min_length);

    F1_2=F1_2(1:min_length);
    F2_2=F2_2(1:min_length);
    F3_2=F3_2(1:min_length);
    F4_2=F4_2(1:min_length);
end

profiles=[F4' F1' F2' F3' F4_2' F1_2' F2_2' F3_2']; %(These could be different lengths)
reflane=2;
if verbos==true
    figure(1)
    plot([F4' F4_2'])
end

sensitivity=10; %initial sensitivity guess will adjust if neeeded
%figure(3)
ladder_assign=identify_ladders(sensitivity,F4,guideruler);%peak identification
%ladder_assign=[0];
while length(ladder_assign)~=length(guideruler)
    %    'ladder_assign - 51'
    %        length(ladder_assign)
    length(guideruler)
    ladder_assign=identify_ladders_gui(sensitivity, F4,guideruler);
end

sensitivity=5; %initial sensitivity guess will adjust if neeeded
%figure(4)
ladder_assign_2=identify_ladders(sensitivity,F4_2,guideruler);
while length(ladder_assign_2)~=length(guideruler)
    %        'ladder_assign 2 - 61'
    %    length(ladder_assign_2)
    %   length(guideruler)
    ladder_assign_2=identify_ladders_gui(sensitivity, F4_2,guideruler);
    %        length(ladder_assign_2)
    %    length(guideruler)
end

%ladder_assign(:,2);
anchorlines=[ladder_assign(:,2) ladder_assign(:,2) ladder_assign(:,2) ladder_assign(:,2) ...
    ladder_assign_2(:,2) ladder_assign_2(:,2) ladder_assign_2(:,2) ladder_assign_2(:,2)];
anchorlines=anchorlines(end:-1:1,:);


profiles_align = calculate_alignedprofiles2(profiles,anchorlines,reflane);

%scale here
% align_base=profiles_align(profiles_align(:,base)~=0,base);
% align_base2=profiles_align(profiles_align(:,base+4)~=0,base+4);

align_base=profiles_align(:,base);
align_base2=profiles_align(:,base+4);

%guess(1)=mean(align_base)/mean(align_base2);
%guess(2)=mean(align_base)-mean(align_base2);

if scale_alignment
    try
        scale=lsqcurvefit(@align_diff,[mean(align_base)/mean(align_base2) mean(align_base)-mean(align_base2)],align_base2,align_base);
    catch
        scale=polyfit(align_base2,align_base,1);
    end
    profiles_align(:,5:8)=scale(1)*profiles_align(:,5:8)+scale(2);
end

if verbos==true
    figure(2)
    plot(profiles_align(:,[1 5]));

    figure(5)
    plot(profiles_align)

    diff=profiles_align(:,[1:4])-profiles_align(:,[5:8]);
    figure(3)
    plot(diff)
end

filenames{1}
filenames{2}

end

function alignV=align_diff(scale,align_scale)
alignV=scale(1)*align_scale+scale(2);
end

function ladder_assign=identify_ladders(sensitivity, F4,guideruler)


[ladders,max_lad]=identify_func(F4, sensitivity);
[ladders, i_lad]=sort(ladders,'descend');
max_lad=max_lad(i_lad);
ladder_assign=assign_ladder(ladders,max_lad,guideruler);

end


function [ladder,max_lad]=identify_func(F,sensitivity)
[tmp,mins]=peakdet(F,mean(F)*sensitivity);
if isempty(tmp)
    ladder=[-1];
    max_lad=[-1];
    return
else
    ladder=tmp(:,1);
    max_lad=tmp(:,2);
end
end

function ladder_assign=assign_ladder(ladders,max_lad,guideruler)
number=min([max(size(ladders)) max(size(guideruler))]);
for i=1:number
    ladder_assign(i,1)=guideruler(i);
    ladder_assign(i,2)=ladders(i);
    ladder_assign(i,3)=max_lad(i);
end
end

function [F1,F2,F3,F4]=read_CEQ_txt(filename)

if nargin<1 || isempty(filename)
    [file,path]=uigetfile('*.txt','Choose txt file');
    filename=fullfile(path,file);
end

fid=fopen(filename,'r');
tline=1;
Sep_start=0;
IND_start=0;
i=0;
j=0;
while tline ~= -1
    tline=fgets(fid);
    if isempty(strfind(tline,'Separation'))==0
        Sep_start=1;
    end

    if isempty(strfind(tline,'INDEX'))==0 & Sep_start==1;
        IND_start=1;
    end

    if Sep_start==1 & IND_start==1
        i=i+1;
    end

    if i>1 & tline ~= -1
        j=j+1;
        [IND(j), LET(j),F1(j),F2(j),F3(j),F4(j),a,b,c,d,e,f,g,h]=...
            strread(tline,'%d%c%d%d%d%d%f%f%f%f%f%f%f%d');
    end

end
fclose(fid);
end

function ladder_assign=identify_ladders_gui(sensitivity, F4,guideruler)

fh=figure('Name','Adjust Sensitivity','NumberTitle','off');
sh = uicontrol(fh,'Style','slider','Max',25,'Min',0,'Value',sensitivity,...
    'SliderStep',[1/25 5/25],'Position',[100 10 130 20],'Callback',@slider_event);
sh2 = uicontrol(fh,'Style','slider','Max',1,'Min',0,'Value',0,...
    'SliderStep',[1/10 5/10],'Position',[250 10 130 20],'Callback',@slider_event);
ah = axes('Parent',fh,'Position',[.15 .15 .7 .7],'box','on');
return_botton = uicontrol(fh,'Style','pushbutton','String','OK','Position',[400 10 60 30],'Callback',@return_button);

cth = uicontrol('Style','text','String',['Sesitivity: ',num2str(get(sh,'Value'))],...
    'Position',[100 35 80 15]);
cth2 = uicontrol('Style','text','String',['Sesitivity: ',num2str(get(sh2,'Value'))],...
    'Position',[250 35 80 15]);
[ladders,max_lad]=identify_func(F4, sensitivity);
[ladders, i_lad]=sort(ladders,'descend');
max_lad=max_lad(i_lad);
ladder_assign=assign_ladder(ladders,max_lad,guideruler);


plot(ah,F4)
hold(ah,'on')
plot(ladders,max_lad,'rx')
plot(ah,ladders,max_lad,'rx')
ladder_size=size(ladder_assign);
if ladder_size(1)>0
    for j=1:ladder_size(1)
        text(ladder_assign(j,2),ladder_assign(j,3),...
            num2str(ladder_assign(j,1)));
    end
end
hold(ah,'off')
num_peaks = uicontrol('Style','text','String',['number of peaks: ',num2str(ladder_size(1))],...
    'Position',[200 370 250 30],'FontSize',20,'ForegroundColor',[1,0,0]);

    function slider_event(hObject,eventdata)
        set(cth,'String',['Sesitivity: ',num2str(get(sh,'Value'))]);
        sensitivityL = get(sh,'Value');
        set(cth2,'String',['Sesitivity: ',num2str(get(sh2,'Value'))]);
        sensitivityS = get(sh2,'Value');

        [ladders,max_lad]=identify_func(F4, sensitivityL+sensitivityS);
        [ladders, i_lad]=sort(ladders,'descend');
        max_lad=max_lad(i_lad);
        ladder_assign=assign_ladder(ladders,max_lad,guideruler);
        plot(ah,F4)
        hold(ah,'on')
        plot(ah,ladders,max_lad,'rx')
        ladder_size=size(ladder_assign);
        if ladder_size(1)>0
            for j=1:ladder_size(1)
                text(ladder_assign(j,2),ladder_assign(j,3),...
                    num2str(ladder_assign(j,1)));
            end
        end
        hold(ah,'off')
        set(num_peaks,'String',['number of peaks: ',num2str(ladder_size(1))]);
    end
    function return_button(hObject,eventdata)

        uiresume(fh);

    end
uiwait;

%mOutputArgs =mIconCData;
% if nargout>0
%     [varargout{1:nargout}] = mOutputArgs{:};
% end
ladder_assign=identify_ladders(get(sh,'Value')+get(sh2,'Value'), F4,guideruler);
close(fh);

end